from .component import Component


class Keyboard(Component):
    """
    Keyboard component representing a keyboard input.

    Contains buttons as subcomponents.
    """

    def render(self):
        """Render keyboard (no-op, keyboards don't render themselves)."""
        pass
